@@ -1,11 +1,6 @@
 
-from flightanalysis.base.table import Table, Time
-from typing import Union
-from flightdata import Flight, Fields
-from pathlib import Path
-from flightanalysis.base.constructs import Constructs, SVar
-from geometry import Point, Quaternion, Base, P0
-from flightanalysis.state import State
+from flightanalysis import Constructs, SVar, Table
+from geometry import Point, Base, P0
 import numpy as np
 from .wind import WindModel, WindModelBuilder
 
@@ -30,13 +25,14 @@ class Air(Base):
 
 
 class Environment(Table):
-    constructs = Table.constructs + Constructs(dict(
-        atm = SVar(Air, ["P", "T", "rho"], lambda tab: Air.iso_sea_level(len(tab))),
-        wind = SVar(Point, ["wvx", "wvy", "wvz"], lambda tab: P0(len(tab)))
-    ))
+    constructs = Table.constructs + Constructs([
+        SVar("atm", Air, ["P", "T", "rho"], lambda tab: Air.iso_sea_level(len(tab))),
+        SVar("wind", Point, ["wvx", "wvy", "wvz"], lambda tab: P0(len(tab)))
+    ])
 
     @staticmethod
-    def build(flight: Flight, sec: State, wmodel: WindModel):
+    def build(flight, sec, wmodel: WindModel):
+        from flightdata import Fields
 
         df = flight.read_fields(Fields.PRESSURE)
         df = df.assign(temperature_0=291.15)
