@@ -1,28 +1,21 @@
 
-from flightanalysis.base.table import Table, Time, SVar
-from typing import Union
-from flightdata import Flight, Fields
-from pathlib import Path
-from flightanalysis.base.constructs import Constructs, SVar
-from flightanalysis.state import State
-from flightanalysis.environment import Environment
-from geometry import Point, Quaternion, Base, PX, Euler
+from flightanalysis import Table, Time, SVar, Constructs, SVar
+from geometry import Point, Base, PX, Euler
 import numpy as np
 
 
-
 class Attack(Base):
     cols = ['alpha', 'beta', 'q']
 
 
 class Flow(Table):
-    constructs = Table.constructs + Constructs(dict(
-        aspd = SVar(Point, ["asx", "asy", "asz"], None),
-        flow = SVar(Point, ["alpha", "beta", "q"], None)
-    ))
+    constructs = Table.constructs + Constructs([
+        SVar("aspd", Point, ["asx", "asy", "asz"], None),
+        SVar("flow", Point, ["alpha", "beta", "q"], None)
+    ])
 
     @staticmethod
-    def build(body: State, env: Environment):
+    def build(body, env):
 #        wind = judge.judging_to_wind(env.wind)
         airspeed = body.vel - body.att.inverse().transform_point(env.wind)
 
