@@ -1,7 +1,7 @@
 """The collectors are serializable functions that return parameters from elements"""
 from flightanalysis.base.collection import Collection
 from . import Opp
-
+from uuid import uuid1
 
 
 class Collector(Opp):
@@ -12,17 +12,20 @@ class Collector(Opp):
 
     def __call__(self, els):
         """return the value"""
+        #this could return a vector in a direction that is useful for assessing visibility
         return els.get_parameter_from_element(self.elname, self.pname)
 
     def __str__(self):
         return self.name
 
     @staticmethod
-    def parse(ins, coll: Collection):
-        try:
-            return Opp.parse(ins, coll)
-        except KeyError:
-            return Collector(*ins.strip(" ").split("."))
+    def parse(ins, name=None):
+        return Opp.parse_f(
+            ins, 
+            lambda ins : Collector(*ins.strip(" ").split(".")),
+            uuid1() if name is None else name
+        )
+        
 
     def to_dict(self):
         return dict(
@@ -30,8 +33,12 @@ class Collector(Opp):
             pname=self.pname
         )
 
+    def copy(self):
+        return Collector(self.elname, self.pname)
+
+
 class Collectors(Collection):
-    VType=Collector
+    VType=Opp
     uid="name"
 
     def __str__(self):
@@ -45,6 +52,13 @@ class Collectors(Collection):
     def from_eldef(el):
         return Collectors([Collector(el.name, pname) for pname in el.Kind.parameters])
     
+    def to_dict(self):
+        return {v.name: str(v) for v in self}
+
+    @staticmethod
+    def from_dict(data):
+        return Collectors({k: Collector.parse(v, k) for k, v in data.items()})
+
     def to_list(self):
         return [str(v) for v in self]
     
@@ -52,5 +66,8 @@ class Collectors(Collection):
     def from_list(data):
         coll = Collectors()
         for d in data:
-            coll.add(Collector.parse(d, coll))
-        return coll
\ No newline at end of file
+            coll.add(Collector.parse(d))
+        return coll
+    
+    def keys(self):
+        return [c.elname for c in self]
\ No newline at end of file
